@@ -13,6 +13,7 @@ class CreateInstancesRequest(AbstractModel):
         self.instanceChargePrepaid = None
         self.instanceTypeId = None
         self.imageId = None
+        self.ipxeUrl = None
         self.resourceGroupId = None
         self.instanceName = None
         self.hostname = None
@@ -26,6 +27,8 @@ class CreateInstancesRequest(AbstractModel):
         self.raidConfig = None
         self.partitions = None
         self.nic = None
+        self.clusterId = None
+        self.enablePrimaryIPv6 = None
 
     def _deserialize(self, params):
         self.zoneId = params.get("zoneId")
@@ -34,6 +37,7 @@ class CreateInstancesRequest(AbstractModel):
             self.instanceChargePrepaid = ChargePrepaid(params.get("instanceChargePrepaid"))
         self.instanceTypeId = params.get("instanceTypeId")
         self.imageId = params.get("imageId")
+        self.ipxeUrl = params.get("ipxeUrl")
         self.resourceGroupId = params.get("imageId")
         self.instanceName = params.get("instanceName")
         self.hostname = params.get("hostname")
@@ -53,6 +57,8 @@ class CreateInstancesRequest(AbstractModel):
                 self.partitions.append(obj)
         if params.get("nic") is not None:
             self.nic = Nic(params.get("nic"))
+        self.clusterId = params.get("clusterId")
+        self.enablePrimaryIPv6 = params.get("enablePrimaryIPv6")
 
 
 class CreateInstancesResponse(AbstractModel):
@@ -385,8 +391,10 @@ class InstanceInfo(AbstractModel):
         self.instanceName = None
         self.hostname = None
         self.instanceTypeId = None
+        self.instanceType = None
         self.imageId = None
         self.imageName = None
+        self.ipxeUrl = None
         self.instanceChargeType = None
         self.bandwidthOutMbps = None
         self.internetChargeType = None
@@ -413,8 +421,10 @@ class InstanceInfo(AbstractModel):
         self.instanceName = params.get("instanceName")
         self.hostname = params.get("hostname")
         self.instanceTypeId = params.get("instanceTypeId")
+        self.instanceType = InstanceType(params.get("instanceType"))
         self.imageId = params.get("imageId")
         self.imageName = params.get("imageName")
+        self.ipxeUrl = params.get("ipxeUrl")
         self.instanceChargeType = params.get("instanceChargeType")
         self.bandwidthOutMbps = params.get("bandwidthOutMbps")
         self.internetChargeType = params.get("internetChargeType")
@@ -501,6 +511,7 @@ class ReinstallInstanceRequest(AbstractModel):
     def __init__(self):
         self.instanceId = None
         self.imageId = None
+        self.ipxeUrl = None
         self.hostname = None
         self.password = None
         self.sshKeys = None
@@ -511,6 +522,7 @@ class ReinstallInstanceRequest(AbstractModel):
     def _deserialize(self, params):
         self.instanceId = params.get("instanceId")
         self.imageId = params.get("imageId")
+        self.ipxeUrl = params.get("ipxeUrl")
         self.hostname = params.get("hostname")
         self.password = params.get("password")
         self.sshKeys = params.get("sshKeys")
@@ -1176,6 +1188,15 @@ class InstanceHealth(AbstractModel):
         self.wanPortStatus = None
         self.serverBrand = None
         self.serverModel = None
+        self.fanStatus = None
+        self.serverBrand = None
+        self.serverModel = None
+        self.cpuTemp = None
+        self.cpu0Temp = None
+        self.cpu1Temp = None
+        self.cpu2Temp = None
+        self.inletTemp = None
+        self.tempUnit = None
 
     def _deserialize(self, params):
         self.instanceId = params.get("instanceId")
@@ -1188,7 +1209,15 @@ class InstanceHealth(AbstractModel):
         self.wanPortStatus = params.get("wanPortStatus")
         self.serverBrand = params.get("serverBrand")
         self.serverModel = params.get("serverModel")
-
+        self.fanStatus = params.get("fanStatus")
+        self.serverBrand = params.get("serverBrand")
+        self.serverModel = params.get("serverModel")
+        self.cpuTemp = params.get("cpuTemp")
+        self.cpu0Temp = params.get("cpu0Temp")
+        self.cpu1Temp = params.get("cpu1Temp")
+        self.cpu2Temp = params.get("cpu2Temp")
+        self.inletTemp = params.get("inletTemp")
+        self.tempUnit = params.get("tempUnit")
 
 class DescribeEipAddressesRequest(AbstractModel):
 
@@ -2464,3 +2493,123 @@ class DescribeSubnetAvailableResourcesResponse(AbstractModel):
     def _deserialize(self, params):
         self.requestId = params.get("requestId")
         self.zoneIdSet = params.get("zoneIdSet")
+
+
+class DescribeManagedInstancesRequest(AbstractModel):
+    def __init__(self):
+        self.instanceIds = None
+        self.instanceName = None
+        self.ip = None
+        self.lanIp = None
+        self.facName = None
+        self.cityCode = None
+        self.pageNum = None
+        self.pageSize = None
+
+    def _deserialize(self, params):
+        self.instanceIds = params.get("instanceIds")
+        self.instanceName = params.get("instanceName")
+        self.ip = params.get("ip")
+        self.lanIp = params.get("lanIp")
+        self.facName = params.get("facName")
+        self.cityCode = params.get("cityCode")
+        self.pageNum = params.get("pageNum")
+        self.pageSize = params.get("pageSize")
+
+
+class DescribeManagedInstancesResponse(AbstractModel):
+    def __init__(self):
+        self.requestId = None
+        self.totalCount = None
+        self.dataSet = None
+
+    def _deserialize(self, params):
+        self.requestId = params.get("requestId")
+        self.totalCount = params.get("totalCount")
+        if params.get("dataSet") is not None:
+            self.dataSet = []
+            for item in params.get("dataSet"):
+                obj = ManagedInstanceInfo(item)
+                self.dataSet.append(obj)
+
+
+class ManagedInstanceInfo(AbstractModel):
+    def __init__(self, params=None):
+        if params is None:
+            params = {}
+        if len(params) > 0:
+            self._deserialize(params)
+            return
+        self.instanceId = None
+        self.instanceName = None
+        self.facName = None
+        self.ips = None
+        self.lanIps = None
+        self.createTime = None
+
+    def _deserialize(self, params):
+        self.instanceId = params.get("instanceId")
+        self.instanceName = params.get("instanceName")
+        self.facName = params.get("facName")
+        self.ips = params.get("ips")
+        self.lanIps = params.get("lanIps")
+        self.createTime = params.get("createTime")
+
+
+
+class DescribeManagedInstanceTrafficRequest(AbstractModel):
+
+    def __init__(self):
+        self.instanceId = None
+        self.startTime = None
+        self.endTime = None
+
+    def _deserialize(self, params):
+        self.instanceId = params.get("instanceId")
+        self.startTime = params.get("startTime")
+        self.endTime = params.get("endTime")
+
+
+class DescribeManagedInstanceTrafficResponse(AbstractModel):
+
+    def __init__(self):
+        self.requestId = None
+        self.dataList = None
+        self.in95 = None
+        self.in95Time = None
+        self.inAvg = None
+        self.inMax = None
+        self.inMin = None
+        self.inTotal = None
+        self.maxBandwidth95ValueMbps = None
+        self.out95 = None
+        self.out95Time = None
+        self.outAvg = None
+        self.outMax = None
+        self.outMin = None
+        self.outTotal = None
+        self.totalUnit = None
+        self.unit = None
+
+    def _deserialize(self, params):
+        self.requestId = params.get("requestId")
+        if params.get("dataList") is not None:
+            self.dataList = []
+            for item in params.get("dataList"):
+                obj = InstanceTrafficData(item)
+                self.dataList.append(obj)
+        self.in95 = params.get("in95")
+        self.in95Time = params.get("in95Time")
+        self.inAvg = params.get("inAvg")
+        self.inMax = params.get("inMax")
+        self.inMin = params.get("inMin")
+        self.inTotal = params.get("inTotal")
+        self.maxBandwidth95ValueMbps = params.get("maxBandwidth95ValueMbps")
+        self.out95 = params.get("out95")
+        self.out95Time = params.get("out95Time")
+        self.outAvg = params.get("outAvg")
+        self.outMax = params.get("outMax")
+        self.outMin = params.get("outMin")
+        self.outTotal = params.get("outTotal")
+        self.totalUnit = params.get("totalUnit")
+        self.unit = params.get("unit")
\ No newline at end of file
